==> ejc-panhuo-impl-3.0.0-20200819.080839-17-sources.jar: com/ejianc/business/panhuo/bean/CategoryEntity.java <==
package com.ejianc.business.panhuo.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 求购物资明细表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_panhuo_category")
public class CategoryEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="wbuy_id")
    private java.lang.Long wbuyId; // 求购主键
    @TableField(value="material_id")
    private java.lang.Long materialId; // 物资主键
    @TableField(value="material_name")
    private java.lang.String materialName; // 物资名称
    @TableField(value="material_type_id")
    private java.lang.Long materialTypeId; // 物资类别末级
    @TableField(value="material_type_name")
    private java.lang.String materialTypeName; // 物资类别末级名称
    @TableField(value="source_id")
    private java.lang.String sourceId; // 物资来源ID
    @TableField(value="system_id")
    private java.lang.Long systemId; // 所属系统ID
    @TableField(value="unit")
    private java.lang.String unit; // 单位
    @TableField(value="brand")
    private java.lang.String brand; // 品牌
    @TableField(value="nums")
    private java.math.BigDecimal nums; // 求购数量
    @TableField(value="spec")
    private java.lang.String spec; // 规格型号
    @TableField(value="note")
    private java.lang.String note; // 备注
    
    
    

    /**
     * 求购主键
     */
    public java.lang.Long getWbuyId() {
        return wbuyId;
    }

    /**
     * 求购主键
     */
    public void setWbuyId(java.lang.Long wbuyId) {
        this.wbuyId = wbuyId;
    }
    /**
     * 物资主键
     */
    public java.lang.Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(java.lang.Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别末级
     */
    public java.lang.Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别末级
     */
    public void setMaterialTypeId(java.lang.Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别末级名称
     */
    public java.lang.String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别末级名称
     */
    public void setMaterialTypeName(java.lang.String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物资来源ID
     */
    public java.lang.String getSourceId() {
        return sourceId;
    }

    /**
     * 物资来源ID
     */
    public void setSourceId(java.lang.String sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 所属系统ID
     */
    public java.lang.Long getSystemId() {
        return systemId;
    }

    /**
     * 所属系统ID
     */
    public void setSystemId(java.lang.Long systemId) {
        this.systemId = systemId;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 品牌
     */
    public java.lang.String getBrand() {
        return brand;
    }

    /**
     * 品牌
     */
    public void setBrand(java.lang.String brand) {
        this.brand = brand;
    }
    /**
     * 求购数量
     */
    public java.math.BigDecimal getNums() {
        return nums;
    }

    /**
     * 求购数量
     */
    public void setNums(java.math.BigDecimal nums) {
        this.nums = nums;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 备注
     */
    public java.lang.String getNote() {
        return note;
    }

    /**
     * 备注
     */
    public void setNote(java.lang.String note) {
        this.note = note;
    }
    
}

==> ejc-panhuo-impl-3.0.0-20200822.073134-28-sources.jar: com/ejianc/business/panhuo/bean/CategoryEntity.java <==
package com.ejianc.business.panhuo.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 求购物资明细表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_panhuo_category")
public class CategoryEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="wbuy_id")
    private java.lang.Long wbuyId; // 求购主键
    @TableField(value="material_id")
    private java.lang.Long materialId; // 物资主键
    @TableField(value="material_code")
    private java.lang.Long materialCode; // 物资编号
    @TableField(value="material_name")
    private java.lang.String materialName; // 物资名称
    @TableField(value="material_type_id")
    private java.lang.Long materialTypeId; // 物资类别末级
    @TableField(value="material_type_name")
    private java.lang.String materialTypeName; // 物资类别末级名称
    @TableField(value="source_id")
    private java.lang.String sourceId; // 物资来源ID
    @TableField(value="system_id")
    private java.lang.Long systemId; // 所属系统ID
    @TableField(value="unit")
    private java.lang.String unit; // 单位
    @TableField(value="brand")
    private java.lang.String brand; // 品牌
    @TableField(value="nums")
    private java.math.BigDecimal nums; // 求购数量
    @TableField(value="spec")
    private java.lang.String spec; // 规格型号
    @TableField(value="note")
    private java.lang.String note; // 备注


    public Long getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(Long materialCode) {
        this.materialCode = materialCode;
    }

    /**
     * 求购主键
     */
    public java.lang.Long getWbuyId() {
        return wbuyId;
    }

    /**
     * 求购主键
     */
    public void setWbuyId(java.lang.Long wbuyId) {
        this.wbuyId = wbuyId;
    }
    /**
     * 物资主键
     */
    public java.lang.Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(java.lang.Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别末级
     */
    public java.lang.Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别末级
     */
    public void setMaterialTypeId(java.lang.Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别末级名称
     */
    public java.lang.String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别末级名称
     */
    public void setMaterialTypeName(java.lang.String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物资来源ID
     */
    public java.lang.String getSourceId() {
        return sourceId;
    }

    /**
     * 物资来源ID
     */
    public void setSourceId(java.lang.String sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 所属系统ID
     */
    public java.lang.Long getSystemId() {
        return systemId;
    }

    /**
     * 所属系统ID
     */
    public void setSystemId(java.lang.Long systemId) {
        this.systemId = systemId;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 品牌
     */
    public java.lang.String getBrand() {
        return brand;
    }

    /**
     * 品牌
     */
    public void setBrand(java.lang.String brand) {
        this.brand = brand;
    }
    /**
     * 求购数量
     */
    public java.math.BigDecimal getNums() {
        return nums;
    }

    /**
     * 求购数量
     */
    public void setNums(java.math.BigDecimal nums) {
        this.nums = nums;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 备注
     */
    public java.lang.String getNote() {
        return note;
    }

    /**
     * 备注
     */
    public void setNote(java.lang.String note) {
        this.note = note;
    }
    
}
